/*
 * Copyright 2011 Cedric Duval <cedricduval@free.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2.
 *
 * See the accompanying COPYING file for more details.
 */

/**
 * \file
 * Parsing hooks for generating a simple commented shell script
 */

#include "config.h"

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <ctype.h>
#include <assert.h>

#include "parse.h"
#include "wbuf.h"



/* --------------------------------------------------------------------------
 *   parsing operations
 */

static void *
init(FILE *out)
{
	return out;
}

static void
cleanup(void *priv)
{
	fclose((FILE *)priv);
}

static int
line_command(void *priv,
             parse_state prev_state,
             char *line,
             char *data,
             size_t len)
{
	fputs(data, (FILE *)priv);

	return 0;
}

static int
line_continuation(void *priv,
                  parse_state prev_state,
                  char *line,
                  char *data,
                  size_t len)
{
	fputs(data, (FILE *)priv);

	return 0;
}

static int
line_other(void *priv,
           parse_state prev_state,
           char *line,
           char *data,
           size_t len)
{
	FILE *out = (FILE *)priv;
	char *p;

	for (p = line; *p && isblank(*p); p++)
		;

	switch (*p) {
	case '#': fputs(line, out); break;
	case '\n': fputc('\n', out); break;
	default: fputs("# ", out); fputs(data, out); break;
	}

	return 0;
}



/* --------------------------------------------------------------------------
 *   operations table
 */

const struct parse_ops parse_ops_gen_script = {
	.init               = init,
	.set_indent         = NULL,
	.line_command       = line_command,
	.line_continuation  = line_continuation,
	.line_output        = NULL,
	.line_other         = line_other,
	.processed_line     = NULL,
	.finalize           = NULL,
	.cleanup            = cleanup,
};
