/*
 * Copyright 2011 Cedric Duval <cedricduval@free.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2.
 *
 * See the accompanying COPYING file for more details.
 */

/**
 * \file
 * Shell spawning
 */

#ifndef _KUULTO_SHELL_H
#define _KUULTO_SHELL_H

#include <sys/types.h> /* pid_t */

/**
 * Start a shell process
 *
 * \parameter[in,out] shfd_in   Input file descriptor for the shell
 * \parameter[in,out] shfd_out  Output file descriptor for the shell
 * \parameter[in]     name      Name within temporary directory
 *
 * \return                      Process ID of the shell, or -1 in case of error
 *
 * The new shell's file descriptors are set as follows:
 * - If shfd_in is -1, a new file descriptor shall be allocated and shfd_in
 *   updated accordingly. Otherwise, using the descriptor specified in shfd_in.
 * - Ditto with shfd_out.
 */
pid_t start_shell(int *shfd_in, int *shfd_out, const char *name);

#endif /* _KUULTO_SHELL_H */
