/*
 * Copyright 2011 Cedric Duval <cedricduval@free.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2.
 *
 * See the accompanying COPYING file for more details.
 */

/**
 * \file
 * Simple write buffer for concatenating strings before printing them out
 */

#ifndef _KUULTO_WBUF_H
#define _KUULTO_WBUF_H

#include <stdbool.h>

/**
 * Initialize a buffer
 *
 * \return  Buffer handle or NULL if it couldn't be allocated
 */
struct wbuf *wbuf_init();

/**
 * Release a buffer
 *
 * \param[in] w  Buffer's handle
 */
void wbuf_free(struct wbuf *w);

/**
 * Append text to a buffer
 *
 * \param[in] w     Buffer's handle
 * \param[in] text  Text to append
 *
 * \return          0 if the text could be appended, -1 otherwise
 */
int wbuf_append(struct wbuf *w, const char *text);

/**
 * Pass content of the buffer to a function
 *
 * \param[in] w     Buffer's handle
 * \param[in] fn    Function
 * \param[in] priv  Private data to function
 *
 * \return          -1 in case of error, 0 otherwise
 */
int wbuf_yield(struct wbuf *w, int (*fn)(void *priv, char *data), void *priv);

/**
 * Query whether a buffer has content to deliver or not
 *
 * \param[in] w  Buffer's handle
 *
 * \return       true if empty, false otherwise
 */
bool wbuf_empty(struct wbuf *w);

#endif /* _KUULTO_WBUF_H */
