 ~~~~~~~~~~~~~~~~~
   Glob matching
 ~~~~~~~~~~~~~~~~~


Star wildcard:

  $ cat <<EOF > star.t
  > All these should match:
  >
  >   $ echo hedgehog
  >   hedge* (glob)
  >
  >   $ echo hedgehog
  >   *hog (glob)
  >
  >   $ echo hedgehog
  >   hed*og (glob)
  >
  >   $ echo hedgehog
  >   *geho* (glob)
  >
  >   $ echo hedgehog
  >   *e*g*g* (glob)
  >
  > And a non-matching one:
  >
  >   $ echo porcupine
  >   *hog* (glob)
  > EOF
  $ kuulto-run1 star.t
   ________________________________________________________________________
  /                                                                  star.t
  All these should match:
  
    $ echo hedgehog
    hedge* (glob)
  
    $ echo hedgehog
    *hog (glob)
  
    $ echo hedgehog
    hed*og (glob)
  
    $ echo hedgehog
    *geho* (glob)
  
    $ echo hedgehog
    *e*g*g* (glob)
  
  And a non-matching one:
  
    $ echo porcupine
    porcupine
  \________________________________________________________________________


Question mark wildcard:

  $ cat <<EOF > question.t
  >   $ echo pig
  >   p?g (glob)
  >
  >   $ echo boar
  >   b??r (glob)
  >
  > But this one should fail:
  >
  >   $ echo hog
  >   ??hog
  > EOF
  $ kuulto-run1 question.t
   ________________________________________________________________________
  /                                                              question.t
    $ echo pig
    p?g (glob)
  
    $ echo boar
    b??r (glob)
  
  But this one should fail:
  
    $ echo hog
    hog
  \________________________________________________________________________


Escaping. It has to be noted that the shell itself also does some escaping,
so backslashes have to be doubled for writing the tests:

  $ cat <<EOF > escape.t
  > Should match the litteral wildcard characters...
  >
  >   $ echo 'spiky*'
  >   spiky\\* (glob)
  >
  >   $ echo 'a?b'
  >   a\\?b (glob)
  >
  > ... but not just anything:
  >
  >   $ echo 'spiking'
  >   spik\\* (glob)
  >
  >   $ echo 'aXb'
  >   a\\?b (glob)
  >
  > And these should match exactly:
  >
  >   $ echo 'c\\\\d'
  >   c\\\\d (glob)
  >
  >   $ echo 'eZf'
  >   e\\Zf (glob)
  > EOF
  $ cat escape.t > /tmp/escape.t
  $ kuulto-run1 escape.t
   ________________________________________________________________________
  /                                                                escape.t
  Should match the litteral wildcard characters...
  
    $ echo 'spiky*'
    spiky\* (glob)
  
    $ echo 'a?b'
    a\?b (glob)
  
  ... but not just anything:
  
    $ echo 'spiking'
    spiking
  
    $ echo 'aXb'
    aXb
  
  And these should match exactly:
  
    $ echo 'c\\d'
    c\\d (glob)
  
    $ echo 'eZf'
    e\Zf (glob)
  \________________________________________________________________________


A mix of glob and exact matches:

  $ cat <<EOF > mix.t
  >   $ for bird in rooster swan swallow magpie condor; do echo \$bird; done
  >   roost* (glob)
  >   swan
  >   *swa* (glob)
  >   magpie
  >   c*r (glob)
  > EOF
  $ kuulto-run1 mix.t
   ________________________________________________________________________
  /                                                                   mix.t
    $ for bird in rooster swan swallow magpie condor; do echo $bird; done
    roost* (glob)
    swan
    *swa* (glob)
    magpie
    c*r (glob)
  \________________________________________________________________________


The end.
