 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   Temporary directory used for tests
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


Creating a test which stores in a file the location where it is executed:

  $ printf "  \$ pwd > $(pwd)/test-pwd\n" > tmpdir.t


Filter displaying the last parts of the stored path:

  $ showdir()
  > {
  >   nb="$1"
  >   testpwd=$(cat test-pwd)
  >
  >   sed 's:^.*\(\(/[^/]*\)\{'"${nb}"'\}\)$:...\1:' test-pwd | tr -d '\n'
  >
  >   [ -d "$(cat test-pwd)" ] && echo " (still around)" \
  >                            || echo " (no longer exists)"
  > }


Running that test file, and checking that it takes place in a temporary
directory bearing the name of the test:

  $ kuulto-run1 tmpdir.t >/dev/null
  $ showdir 1
  .../tmpdir.t (no longer exists)


Same test file, but this time with the -k option to indicate that the
test directory should be kept:

  $ kuulto-run1 -k tmpdir.t >/dev/null 2>&1
  $ showdir 1
  .../tmpdir.t (still around)


Now forcing where the test will be executed through the environment,
absolute path. It should be preserved even without -k:

  $ mkdir -p my/dandy/tmpdir
  $ KUULTO_TMPDIR=$(pwd)/my/dandy/tmpdir kuulto-run1 tmpdir.t >/dev/null
  $ showdir 4
  .../my/dandy/tmpdir/tmpdir.t (still around)


Same thing, but with a relative path:

  $ mkdir -p my/nifty/tmpdir
  $ KUULTO_TMPDIR=./my/nifty/tmpdir kuulto-run1 tmpdir.t >/dev/null
  $ showdir 4
  .../my/nifty/tmpdir/tmpdir.t (still around)


Forcing the use of a non existent directory. Should fail:

  $ KUULTO_TMPDIR=./my/groovy/tmpdir kuulto-run1 tmpdir.t >/dev/null 2>&1 \
  >   && echo "OK."                                                       \
  >   || echo "Failed."
  Failed.


Executing the same test several times in the same forced location.
All tests should be executed in a different directory:

  $ mkdir -p my/peachy/tmpdir
  $ KUULTO_TMPDIR=./my/peachy/tmpdir kuulto-run1 tmpdir.t >/dev/null
  $ showdir 4
  .../my/peachy/tmpdir/tmpdir.t (still around)
  $ KUULTO_TMPDIR=./my/peachy/tmpdir kuulto-run1 tmpdir.t >/dev/null
  $ showdir 4
  .../my/peachy/tmpdir/tmpdir.t.1 (still around)
  $ KUULTO_TMPDIR=./my/peachy/tmpdir kuulto-run1 tmpdir.t >/dev/null
  $ showdir 4
  .../my/peachy/tmpdir/tmpdir.t.2 (still around)


Displaying the resulting content of the top-level test directory:

  $ ls -1 my/peachy/tmpdir | sort
  tmpdir.t
  tmpdir.t.1
  tmpdir.t.2


The end.
